==> haskell-language-c-0.7.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.7.1
id: language-c-0.7.1-IGeGUhRFB0oKu0O8FPLNrc
key: language-c-0.7.1-IGeGUhRFB0oKu0O8FPLNrc
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.
category: Language
author: AUTHORS
exposed: True
indefinite: False
exposed-modules:
    Language.C Language.C.Analysis Language.C.Analysis.AstAnalysis
    Language.C.Analysis.Builtins Language.C.Analysis.ConstEval
    Language.C.Analysis.Debug Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.DefTable Language.C.Analysis.Export
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.SemError
    Language.C.Analysis.SemRep Language.C.Analysis.TravMonad
    Language.C.Analysis.TypeCheck Language.C.Analysis.TypeConversions
    Language.C.Analysis.TypeUtils Language.C.Data Language.C.Data.Error
    Language.C.Data.Ident Language.C.Data.InputStream
    Language.C.Data.Name Language.C.Data.Node Language.C.Data.Position
    Language.C.Parser Language.C.Pretty Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.System.GCC
    Language.C.System.Preprocess
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
abi: 8f6b65fa4f2152fe84a6cae25706a3ef
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/language-c-0.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/language-c-0.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/language-c-0.7.1
hs-libraries: HSlanguage-c-0.7.1-IGeGUhRFB0oKu0O8FPLNrc
depends:
    filepath-1.4.1.2 base-4.10.1.0 process-1.6.1.0 directory-1.3.0.2
    array-0.5.2.0 containers-0.5.10.2 pretty-1.1.3.3
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 bytestring-0.10.8.2
abi-depends: filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-c-0.7.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.7.2
id: language-c-0.7.2-80gnm5tZIr6FsKNoqtp2DN
key: language-c-0.7.2-80gnm5tZIr6FsKNoqtp2DN
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.
category: Language
author: AUTHORS
exposed: True
indefinite: False
exposed-modules:
    Language.C Language.C.Analysis Language.C.Analysis.AstAnalysis
    Language.C.Analysis.Builtins Language.C.Analysis.ConstEval
    Language.C.Analysis.Debug Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.DefTable Language.C.Analysis.Export
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.SemError
    Language.C.Analysis.SemRep Language.C.Analysis.TravMonad
    Language.C.Analysis.TypeCheck Language.C.Analysis.TypeConversions
    Language.C.Analysis.TypeUtils Language.C.Data Language.C.Data.Error
    Language.C.Data.Ident Language.C.Data.InputStream
    Language.C.Data.Name Language.C.Data.Node Language.C.Data.Position
    Language.C.Parser Language.C.Pretty Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.System.GCC
    Language.C.System.Preprocess
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
abi: c858bb22f75eae736b990fa6b325af95
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/language-c-0.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/language-c-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/language-c-0.7.2
hs-libraries: HSlanguage-c-0.7.2-80gnm5tZIr6FsKNoqtp2DN
depends:
    filepath-1.4.1.2 base-4.10.1.0 process-1.6.1.0 directory-1.3.0.2
    array-0.5.2.0 containers-0.5.10.2 pretty-1.1.3.3
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 bytestring-0.10.8.2
abi-depends: filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
